/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.action;

import java.awt.event.*;

import javax.swing.event.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.undo.*;
import edu.stanford.smi.protege.resource.*;

/**
 * Redo the previous undone action.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class RedoAction extends ProjectAction {

    public RedoAction(boolean large) {
        super(ResourceKey.REDO_ACTION, large);
        CommandManager manager = getCommandManager();
        if (manager == null) {
            setEnabled(false);
        } else {
            setEnabled(manager.canRedo());
            manager.addChangeListener(new ChangeListener() {
                public void stateChanged(ChangeEvent event) {
                    setEnabled(getCommandManager().canRedo());
                }
            });
        }
    }

    public void actionPerformed(ActionEvent event) {
        getKnowledgeBase().getCommandManager().redo();
    }

    public Object getValue(String key) {
        Object value = super.getValue(key);
        if (key.equals(NAME)) {
            // Log.stack("", this, "getValue", key);
            CommandManager commandManager = getCommandManager();
            if (commandManager != null) {
                Command command = commandManager.getRedoCommand();
                if (command != null) {
                    String s = command.getDescription();
                    value = value.toString() + " (" + s + ")";
                }
            }
        }
        return value;
    }

}
