/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore;

import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Set;

import edu.stanford.smi.protege.model.Facet;
import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.Slot;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.server.framestore.ServerFrameStore;

/**
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class ClosureUtils {

    public static Set calculateClosure(
            NarrowFrameStore store,
            Frame frame,
            Slot slot,
            Facet facet,
            boolean isTemplate) {
        RemoteSession session = ServerFrameStore.getCurrentSession();
        try {
            store.setCaching(session, false);
            return calculateClosure(store, frame, slot, facet, isTemplate, new LinkedHashSet());
        }
        finally {
            store.setCaching(session, true);
        }
    }

    // TODO It would be preferable if this method returned a breadth first closure
    private static Set calculateClosure(
        NarrowFrameStore store,
        Frame frame,
        Slot slot,
        Facet facet,
        boolean isTemplate,
        Set values) {
        Iterator i = store.getValues(frame, slot, facet, isTemplate).iterator();
        while (i.hasNext()) {
            Object o = i.next();
            boolean changed = values.add(o);
            if (changed && o instanceof Frame) {
                calculateClosure(store, (Frame) o, slot, facet, isTemplate, values);
            }
        }
        return values;
    }

}
