/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.storage.database;

import java.util.logging.Level;
import java.util.logging.Logger;

import edu.stanford.smi.protege.util.Log;

/**
 * <p>
 * Title: DatabaseFrameDbFactory
 * </p>
 * <p>
 * Description: Factory to create instances of {@link DatabaseFrameDb}
 * </p>
 * <p>
 * Copyright: Copyright (c) 2008
 * </p>
 * <p>
 * Company: Clark & Parsia, LLC. <http://www.clarkparsia.com>
 * </p>
 * 
 * @author Mike Smith
 */
public class DatabaseFrameDbFactory {

	final private static Logger						log	= Log
																.getLogger( DatabaseFrameDbFactory.class );



	public static DatabaseFrameDb createDatabaseFrameDb(Class<? extends DatabaseFrameDb> clz) {
		try {
			return clz.newInstance();
		} catch( InstantiationException e ) {
			log.log( Level.SEVERE, "Failed to instantiate DatabaseFrameDb", e );
			return null;
		} catch( IllegalAccessException e ) {
			log.log( Level.SEVERE, "Illegal access exception while creating DatabaseFrameDb", e );
			return null;
		}
	}
	
	public static Class<? extends DatabaseFrameDb> getFrameDbClass(String className) {
	    Class<? extends DatabaseFrameDb> dbFrameDbClass = DefaultDatabaseFrameDb.class;
	    if( className != null ) {
	        try {
	            Class<?> clazz = Class.forName( className );
	            dbFrameDbClass = clazz.asSubclass( DatabaseFrameDb.class );
	        } catch( ClassNotFoundException e ) {
	            log.warning( className + " not found, using default DatabaseFrameDb" );
	        } catch( ClassCastException e ) {
	            log.warning( className
	                         + " does not implement DatabaseFrameDb, using default DatabaseFrameDb" );
	        }
	    }
	    return dbFrameDbClass;
	}
}
