/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

/**
 * 
 */
package edu.stanford.smi.protege.storage.database;

import edu.stanford.smi.protege.util.ApplicationProperties;

public enum DatabaseProperty {
    DRIVER_PROPERTY("driver", "com.mysql.jdbc.Driver", "JDBC Driver Class Name"),
    TABLENAME_PROPERTY("table", "ProtegeTable", "Table"),
    URL_PROPERTY("url", "jdbc:mysql://localhost/protege", "JDBC URL"),
    USERNAME_PROPERTY("username", null, "Username"),
    PASSWORD_PROPERTY("password", null, "Password");
    
    private String name;
    private String defaultValue;
    private String title;
    
    private DatabaseProperty(String name, String defaultValue, String title) {
        this.name = name;
        this.defaultValue = defaultValue;
        this.title = title;
    }
    
    public String getName() {
        return name;
    }
    
    public String getDefaultValue() {
        return  defaultValue;
    }
    
    public String getTitle() {
        return title;
    }

    public static String getProperty(DatabaseProperty property) {
        return ApplicationProperties.getString(getPropertyName(property.getName()), property.getDefaultValue());
    }

    public static void setProperty(DatabaseProperty property, String value) {
        ApplicationProperties.setString(getPropertyName(property.getName()), value);
    }

    private static String getPropertyName(String baseName) {
        return DatabaseKnowledgeBaseSourcesEditor.class.getName() + "." + baseName;
    }
}