/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.ui;

import java.awt.*;
import java.nio.charset.*;
import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.util.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class EncodingsPanel extends JPanel {
    private JComboBox readEncodingComboBox;
    // private JComboBox writeEncodingComboBox;

    public EncodingsPanel() {
        super(new BorderLayout());
        add(createEncodingsPanel(), BorderLayout.CENTER);
        add(createLocalePanel(), BorderLayout.SOUTH);
    }

    private JComponent createEncodingsPanel() {
        JPanel panel = new JPanel(new GridLayout(2, 1));
        panel.setBorder(BorderFactory.createTitledBorder("Encodings"));
        panel.add(createCurrentEncoding());
        panel.add(createReadEncodingOverride());
        // panel.add(createWriteEncodingOverride());
        return panel;
    }

    private static JComponent createCurrentEncoding() {
        JTextField textField = ComponentFactory.createTextField();
        textField.setEnabled(false);
        textField.setText(SystemUtilities.getFileEncoding());
        return new LabeledComponent("Default", textField);
    }

    private JComponent createReadEncodingOverride() {
        readEncodingComboBox = ComponentFactory.createComboBox();
        readEncodingComboBox.setModel(getEncodingModel());
        readEncodingComboBox.setSelectedItem(getCurrentReadEncodingOverride());
        readEncodingComboBox.setRenderer(new CharsetRenderer());
        return new LabeledComponent("Read Override", readEncodingComboBox);
    }

    private static String getCurrentReadEncodingOverride() {
        String override = FileUtilities.getReadEncodingOverride();
        if (override != null) {
            Charset charset = Charset.forName(override);
            override = charset.name();
        }
        return override;
    }

    private static ComboBoxModel getEncodingModel() {
        Collection charsets = Charset.availableCharsets().keySet();
        DefaultComboBoxModel model = new DefaultComboBoxModel(charsets.toArray());
        model.insertElementAt(null, 0);
        return model;
    }

    private static JComponent createLocalePanel() {
        JTextField field = ComponentFactory.createTextField();
        field.setEnabled(false);
        String text = Locale.getDefault().getDisplayName(Locale.ENGLISH);
        field.setText(text);
        return new LabeledComponent("Locale", field);
    }

    public void commitChanges() {
        String override = (String) readEncodingComboBox.getSelectedItem();
        FileUtilities.setReadEncodingOverride(override);
    }

}

class CharsetRenderer extends DefaultRenderer {
    public void load(Object o) {
        if (o instanceof String) {
            String charsetName = (String) o;
            Charset charset = Charset.forName(charsetName);
            String text = charset.name();
            setMainText(text);
        } else {
            setMainText("<none>");
        }
    }

    public void loadNull() {
        setMainText("");
    }
}
