/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.util.logging.Level;


/**
 * Default implementation of the {@link ErrorHandler} interface.
 * 
 * <p>
 * The default behaviour is:
 * <li> <b>warning</b> - do nothing, just log the warning </li>
 * <li> <b>error</b> - do nothing, just log the error </li>
 * <li> <b>fatal error</b> - rethrow the exception </li>
 * </p>
 * 
 * @see ErrorHandler
 * 
 * @author Tania Tudorache <tudorache@stanford.edu>
 *
 * @param <X>
 */
public class DefaultErrorHandler<X extends Throwable> implements ErrorHandler<X> {
    private boolean error = false;

	public void warning(X e) throws X {
		Log.getLogger().log(Level.WARNING, "Warning:  " + e.getMessage(), e);		
	}

	public void error(X e) throws X {
	    error = true;
		Log.getLogger().log(Level.WARNING, "Error: " + e.getMessage(), e);		
	}

	public void fatalError(X e) throws X {
	    error = true;
		throw e;		
	}
	
	public void clear() {
	    error = false;
	}
	
	public boolean hasError() {
	    return error;
	}
	
	
}
