/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

/**
 * An adapter that causes the raw "mouse clicked" event to fire an action if the real event is actually a double click. 
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class DoubleClickActionAdapter extends MouseAdapter {
    private Action _action;

    public DoubleClickActionAdapter(Action initialAction) {
        _action = initialAction;
    }

    public void mouseClicked(MouseEvent event) {
        if (event.getClickCount() == 2 && !event.isMetaDown() && wantDoubleClick(event)) {
            ActionEvent actionEvent = new ActionEvent(event.getSource(), ActionEvent.ACTION_PERFORMED, null);
            _action.actionPerformed(actionEvent);
        }
    }

    private static boolean wantDoubleClick(MouseEvent event) {
        boolean wantDoubleClick = true;
        Object source = event.getSource();
        if (source instanceof JTree) {
            JTree tree = (JTree) source;
            Point point = event.getPoint();
            int eventLocation = tree.getRowForLocation(point.x, point.y);
            int[] rows = tree.getSelectionRows();
            if (rows != null && rows[0] != eventLocation) {
                wantDoubleClick = false;
            }
        }
        return wantDoubleClick;
    }
}
