/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.lang.reflect.Proxy;
import java.rmi.Remote;
import java.util.*;

import edu.stanford.smi.protege.model.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class LocalizeUtils {

    public static void localize(Object o, KnowledgeBase kb) {
        if (o == null) {
            // do nothing
        } else if (o instanceof Collection) {
            localizeCollection((Collection) o, kb);
        } else if (o instanceof Map) {
            localizeMap((Map) o, kb);
        } else if (o instanceof Localizable) {
            ((Localizable) o).localize(kb);
        } else if (o instanceof Remote && o instanceof Proxy) {
            ;
        } else if (!isPrimative(o)) {
            Log.getLogger().warning("Unhandled localization: " + o);
        }
    }

    private static boolean isPrimative(Object o) {
        return o instanceof String || o instanceof Boolean || o instanceof Integer || o instanceof Float;
    }

    private static void localizeCollection(Collection values, KnowledgeBase kb) {
        Iterator i = values.iterator();
        while (i.hasNext()) {
            Object o = i.next();
            localize(o, kb);
        }
    }

    private static void localizeMap(Map values, KnowledgeBase kb) {
        Iterator i = values.entrySet().iterator();
        while (i.hasNext()) {
            Map.Entry entry = (Map.Entry) i.next();
            localize(entry.getKey(), kb);
            localize(entry.getValue(), kb);
        }
    }
}